@@ -2,9 +2,10 @@
 
 set -e
 
-# Read and export debian specific configuration
-# Only exported variables will be passed on to gitlab app
-export $(cat /etc/gitlab/gitlab-debian.conf)
+# Read debian specific configuration
+. /etc/gitlab/gitlab-debian.conf
+export DB RAILS_ENV
+
 cd /usr/share/gitlab
 
 # Check if the db is already present
@@ -25,4 +26,4 @@ fi
 chmod 0700 ${gitlab_data_dir}/.gitlab_shell_secret
 
 echo "Precompiling assets..."
-su ${gitlab_user} -s /bin/sh -c 'bundle exec rake tmp:cache:clear assets:precompile RAILS_ENV=production'
+su ${gitlab_user} -s /bin/sh -c 'bundle exec rake tmp:cache:clear assets:precompile'
